# Generated by Django 4.2 on 2026-02-22 14:23

import wagtail.blocks
import wagtail.fields
import wagtail.snippets.blocks
from django.db import migrations

import wagtail_lms.models


class Migration(migrations.Migration):
    dependencies = [
        (
            "wagtail_lms",
            "0002_h5pactivity_lessonpage_h5pattempt_h5pxapistatement_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="lessonpage",
            name="body",
            field=wagtail.fields.StreamField(
                [
                    ("paragraph", wagtail.blocks.RichTextBlock()),
                    (
                        "h5p_activity",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "activity",
                                    wagtail.snippets.blocks.SnippetChooserBlock(
                                        wagtail_lms.models.H5PActivity
                                    ),
                                )
                            ]
                        ),
                    ),
                ],
                blank=True,
            ),
        ),
    ]
